@@ -2,35 +2,25 @@
 from contextlib import contextmanager
 from http.server import HTTPServer
 import threading
+from typing import Generator
 
-from httpdbg.hooks import set_hook_for_all_libs
-from httpdbg.hooks import unset_hook_for_all_libs
+from httpdbg.exception import HttpdbgException
 from httpdbg.records import HTTPRecords
 from httpdbg.webapp import HttpbgHTTPRequestHandler
 
 
 @contextmanager
-def httpdbg(records=None):
-    if records is None:
-        records = HTTPRecords()
-    try:
-        set_hook_for_all_libs(records)
-
-        yield records
-
-        unset_hook_for_all_libs(records)
-    except Exception as ex:
-        unset_hook_for_all_libs(records)
-        raise ex
-
-
-@contextmanager
-def httpdbg_srv(port):
+def httpdbg_srv(host: str, port: int) -> Generator[HTTPRecords, None, None]:
     server = None
     records = HTTPRecords()
     try:
-        server = ServerThread(port, records)
-        server.start()
+        try:
+            server = ServerThread(host, port, records)
+            server.start()
+        except Exception as ex_server_start:
+            raise HttpdbgException(
+                f"An issue occurred while starting the httpdbg web interface: [{str(ex_server_start)}]"
+            )
 
         yield records
 
@@ -42,14 +32,17 @@ def httpdbg_srv(port):
 
 
 class ServerThread(threading.Thread):
-    def __init__(self, port, records):
+    def __init__(self, host: str, port: int, records: HTTPRecords) -> None:
         threading.Thread.__init__(self)
         self.port = port
 
         def http_request_handler(*args, **kwargs):
             HttpbgHTTPRequestHandler(records, *args, **kwargs)
 
-        self.srv = HTTPServer(("localhost", port), http_request_handler)
+        self.srv = HTTPServer((host, port), http_request_handler)
+        records.ignore += (
+            (str(self.srv.server_address[0]), self.srv.server_address[1]),
+        )
 
     def run(self):
         self.srv.serve_forever()
